@@ -328,18 +328,27 @@ fr_command_arj_get_mime_types (FrCommand *comm)
 
 FrCommandCap
 fr_command_arj_get_capabilities (FrCommand  *comm,
-			         const char *mime_type)
+			         const char *mime_type,
+				 gboolean    check_command)
 {
 	FrCommandCap capabilities;
 
 	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES | FR_COMMAND_CAN_ENCRYPT;
-	if (is_program_in_path ("arj"))
+	if (is_program_available ("arj", check_command))
 		capabilities |= FR_COMMAND_CAN_READ_WRITE;
 
 	return capabilities;
 }
 
 
+static const char *
+fr_command_arj_get_packages (FrCommand  *comm,
+			     const char *mime_type)
+{
+	return PACKAGES ("arj");
+}
+
+
 static void
 fr_command_arj_class_init (FrCommandArjClass *class)
 {
@@ -359,6 +368,7 @@ fr_command_arj_class_init (FrCommandArjClass *class)
 	afc->handle_error     = fr_command_arj_handle_error;
 	afc->get_mime_types   = fr_command_arj_get_mime_types;
 	afc->get_capabilities = fr_command_arj_get_capabilities;
+	afc->get_packages     = fr_command_arj_get_packages;
 }
 
 
